API Reference
=============

TodoTxt
-------

.. autoclass:: pytodotxt.TodoTxt
   :members:
   :special-members: __init__


Task
----

.. autoclass:: pytodotxt.Task
   :members:
   :special-members: __init__


TodoTxtParser
-------------

.. autoclass:: pytodotxt.TodoTxtParser
   :members:
   :special-members: __init__

